@@ -266,7 +266,7 @@
 	@$db->updatequery("ALTER TABLE `system` ADD `warning_remain_count` int(11) NOT NULL default '10'");
         @$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call` tinyint(1) NOT NULL");
         @$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call_c` int(11) NOT NULL default '1'");
-	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call_msg` varchar(64) NOT NULL default 'Unassigned (unallocated) number'");
+	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_s_call_msg` varchar(256) NOT NULL default 'Unassigned (unallocated) number'");
 	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_low_asr` tinyint(1) NOT NULL default '0'");
 	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_asr_number` int(11) unsigned NOT NULL default '10'");
 	@$db->updatequery("ALTER TABLE `system` ADD `auto_disable_asr_threshold` int(11) unsigned NOT NULL default '15'");
@@ -344,6 +344,16 @@
 	}
 	
 /*1.6.4 add hb fail*/
+	@$db->updatequery("ALTER TABLE  `logs` CHANGE  `value`  `value` INT( 32 ) NOT NULL");
+	if(!$rs || $rs[0] < 110){
+		@$db->updatequery("update `system` set `version`='110'");
+		@$db->updatequery("ALTER TABLE `logs` ADD INDEX (`value`)");
+	}
+	
+/*1.6.5*/
+        @$db->updatequery("ALTER TABLE `system` ADD `auto_reboot_s_call` tinyint(1) NOT NULL");
+	@$db->updatequery("ALTER TABLE `system` ADD `auto_reboot_s_call_msg` varchar(256) NOT NULL default 'Unassigned (unallocated) number'");
+	
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 
